@@ -16,7 +16,7 @@ Example usage:
 u'Cabin Fever'
 """
 __author__ = "dbr/Ben"
-__version__ = "1.2.2"
+__version__ = "1.3"
 
 import os
 import sys
@@ -359,13 +359,14 @@ class Tvdb:
         ]
 
         if language is None:
-            self.config['language'] = "en"
-        elif language not in self.config['valid_languages']:
-            raise ValueError("Invalid language %s, options are: %s" % (
-                language, self.config['valid_languages']
-            ))
+            self.config['language'] = None
         else:
-            self.config['language'] = language
+            if language not in self.config['valid_languages']:
+                raise ValueError("Invalid language %s, options are: %s" % (
+                    language, self.config['valid_languages']
+                ))
+            else:
+                self.config['language'] = language
 
         # The following url_ configs are based of the
         # http://thetvdb.com/wiki/index.php/Programmers_API
@@ -376,9 +377,9 @@ class Tvdb:
         else:
             self.config['url_getSeries'] = "%(base_url)s/api/GetSeries.php?seriesname=%%s&language=%(language)s" % self.config
 
-        self.config['url_epInfo'] = "%(base_url)s/api/%(apikey)s/series/%%s/all/%(language)s.xml" % self.config
+        self.config['url_epInfo'] = "%(base_url)s/api/%(apikey)s/series/%%s/all/%%s.xml" % self.config
 
-        self.config['url_seriesInfo'] = "%(base_url)s/api/%(apikey)s/series/%%s/%(language)s.xml" % self.config
+        self.config['url_seriesInfo'] = "%(base_url)s/api/%(apikey)s/series/%%s/%%s.xml" % self.config
         self.config['url_actorsInfo'] = "%(base_url)s/api/%(apikey)s/series/%%s/actors.xml" % self.config
 
         self.config['url_seriesBanner'] = "%(base_url)s/api/%(apikey)s/series/%%s/banners.xml" % self.config
@@ -454,7 +455,7 @@ class Tvdb:
 
     def _setItem(self, sid, seas, ep, attrib, value):
         """Creates a new episode, creating Show(), Season() and
-        Episode()s as required. Called by _getShowData to populute
+        Episode()s as required. Called by _getShowData to populate show
 
         Since the nice-to-use tvdb[1][24]['name] interface
         makes it impossible to do tvdb[1][24]['name] = "name"
@@ -506,11 +507,9 @@ class Tvdb:
         seriesEt = self._getetsrc(self.config['url_getSeries'] % (series))
         allSeries = []
         for series in seriesEt:
-            sn = series.find('SeriesName')
-            value = self._cleanData(sn.text)
-            cur_sid = series.find('id').text
-            self.log.debug('Found series %s (id: %s)' % (value, cur_sid))
-            allSeries.append( {'sid':cur_sid, 'name':value} )
+            result = dict((k.tag.lower(), k.text) for k in series.getchildren())
+            self.log.debug('Found series %(seriesname)s' % result)
+            allSeries.append(result)
         #end for series
 
         if len(allSeries) == 0:
@@ -525,7 +524,7 @@ class Tvdb:
                 self.log.debug('Auto-selecting first search result using BaseUI')
                 ui = BaseUI(config = self.config, log = self.log)
             else:
-                self.log.debug('Interactivily selecting show using ConsoleUI')
+                self.log.debug('Interactively selecting show using ConsoleUI')
                 ui = ConsoleUI(config = self.config, log = self.log)
             #end if config['interactive]
         #end if custom_ui != None
@@ -569,14 +568,12 @@ class Tvdb:
             if not bid in banners[btype][btype2]:
                 banners[btype][btype2][bid] = {}
 
-            self.log.debug("Banner: %s", bid)
             for cur_element in cur_banner.getchildren():
                 tag = cur_element.tag.lower()
                 value = cur_element.text
                 if tag is None or value is None:
                     continue
                 tag, value = tag.lower(), value.lower()
-                self.log.debug("Banner info: %s = %s" % (tag, value))
                 banners[btype][btype2][bid][tag] = value
 
             for k, v in banners[btype][btype2][bid].items():
@@ -584,7 +581,6 @@ class Tvdb:
                     new_key = "_%s" % (k)
                     self.log.debug("Transforming %s to %s" % (k, new_key))
                     new_url = self.config['url_artworkPrefix'] % (v)
-                    self.log.debug("New banner URL: %s" % (new_url))
                     banners[btype][btype2][bid][new_key] = new_url
 
         self._setShowData(sid, "_banners", banners)
@@ -631,15 +627,29 @@ class Tvdb:
             cur_actors.append(curActor)
         self._setShowData(sid, '_actors', cur_actors)
 
-    def _getShowData(self, sid):
+    def _getShowData(self, sid, language):
         """Takes a series ID, gets the epInfo URL and parses the TVDB
         XML file into the shows dict in layout:
         shows[series_id][season_number][episode_number]
         """
 
+        if self.config['language'] is None:
+            self.log.debug('Config language is none, using show language')
+            getShowInLanguage = language
+        else:
+            self.log.debug(
+                'Configured language %s override show language of %s' % (
+                    self.config['language'],
+                    language
+                )
+            )
+            getShowInLanguage = self.config['language']
+
         # Parse show information
         self.log.debug('Getting all series data for %s' % (sid))
-        seriesInfoEt = self._getetsrc(self.config['url_seriesInfo'] % (sid))
+        seriesInfoEt = self._getetsrc(
+            self.config['url_seriesInfo'] % (sid, getShowInLanguage)
+        )
         for curInfo in seriesInfoEt.findall("Series")[0]:
             tag = curInfo.tag.lower()
             value = curInfo.text
@@ -651,7 +661,6 @@ class Tvdb:
                     value = self._cleanData(value)
 
             self._setShowData(sid, tag, value)
-            self.log.debug("Got info: %s = %s" % (tag, value))
         #end for series
 
         # Parse banners
@@ -664,7 +673,7 @@ class Tvdb:
 
         # Parse episode data
         self.log.debug('Getting all episodes of %s' % (sid))
-        epsEt = self._getetsrc( self.config['url_epInfo'] % (sid) )
+        epsEt = self._getetsrc( self.config['url_epInfo'] % (sid, language) )
 
         for cur_ep in epsEt.findall("Episode"):
             seas_no = int(cur_ep.find('SeasonNumber').text)
@@ -692,11 +701,11 @@ class Tvdb:
         else:
             self.log.debug('Getting show %s' % (name))
             selected_series = self._getSeries( name )
-            sname, sid = selected_series['name'], selected_series['sid']
-            self.log.debug('Got %s, sid %s' % (sname, sid))
+            sname, sid = selected_series['seriesname'], selected_series['id']
+            self.log.debug('Got %(seriesname)s, id %(id)s' % selected_series)
 
             self.corrections[name] = sid
-            self._getShowData(sid)
+            self._getShowData(selected_series['id'], selected_series['language'])
         #end if name in self.corrections
         return sid
     #end _nameToSid
@@ -708,7 +717,7 @@ class Tvdb:
         if isinstance(key, (int, long)):
             # Item is integer, treat as show id
             if key not in self.shows:
-                self._getShowData(key)
+                self._getShowData(key, self.config['language'])
             return self.shows[key]
         
         key = key.lower() # make key lower case
